@@ -1,6 +1,6 @@
 aggregate_ST_temporal = function(x, by, FUN = mean, ..., simplify = TRUE) {
 	stopifnot("data" %in% slotNames(x))
-	#require(zoo) # otherwise, missing MATCH errors appear later on.
+	FUN = match.fun(FUN)
 	x = as(x, "STFDF")
 	if (is.function(by))
 		cc = by(index(x@time)) # time format index
@@ -38,6 +38,7 @@ setMethod("aggregateBy", signature(x = "STFDF", by = "Spatial"),
 	function(x, by, FUN = mean, ..., simplify = TRUE, 
 			byTime = is(x, "STF") || is(x, "STS")) {
 		stopifnot("data" %in% slotNames(x))
+		FUN = match.fun(FUN)
 		if (is(by, "SpatialGrid"))
 			by = as(by, "SpatialPixels")
 		if (byTime) {
@@ -66,6 +67,7 @@ setMethod("aggregateBy", signature(x = "STFDF", by = "Spatial"),
 
 aggregateBySTST = function(x, by, FUN = mean, ..., simplify = TRUE) {
 	stopifnot("data" %in% slotNames(x))
+	FUN = match.fun(FUN)
    	by0 = by
    	if (gridded(by@sp))
       	by@sp = as(by@sp, "SpatialPolygons")
@@ -94,12 +96,13 @@ aggregate.ST = function(x, by, FUN, ..., simplify = TRUE)
 	aggregateBy(x, by, FUN, simplify = simplify, ...)
 
 aggregate.STFDF = function(x, by, FUN, ..., simplify = TRUE) {
+	FUN = match.fun(FUN)
 	if (identical(by, "time"))
 		addAttrToGeom(x@sp,
-			as.data.frame(apply(as.array(x), c(1,3), FUN)),
+			as.data.frame(apply(as.array(x), c(1,3), FUN, ...)),
 			FALSE)
 	else if (identical(by, "space"))
-		xts(apply(as.array(x), c(2,3), FUN), index(x@time))
+		xts(apply(as.array(x), c(2,3), FUN, ...), index(x@time))
 	else
 		aggregate.ST(x, by, FUN, ..., simplify = simplify)
 }
